ipywidgets: Interactive HTML widgets for Jupyter notebooks and the IPython kernel
=================================================================================

Description
-----------

Interactive HTML widgets for Jupyter notebooks and the IPython kernel.
